pub enum Operator {
Equal,
Other,
}Expand description
Operator in an assignment statement
Operator::Equal: the variable in LHS clears it own value and create a data dependency on all variables in RHS
x = y;
KILL(x), USE(Y)
```javascript
- `Operator::Other` : the variable in LHS is modified by using both its value and
RHS
```javascript
x += y;
USE(x), USE(y)Variants